#

    	objectives

    		browser cache:

    			https://web.dev/articles/http-cache

    			https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Cache-Control

    			etag:
    				https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/ETag

    			request:
    				If-None-Match: W/"32f-ocZpOyPZZyg+7TCyJEV3si5izKM"

    			responses:
    				Etag: W/"32f-ocZpOyPZZyg+7TCyJEV3si5izKM"

    				Cache-Control:
    					no-cache
    						cache the response, but revalidate with the Etag
    						for instance check for latest HTML

    					no-store

    					must-revalidate

    					private
    						can only be cached by the browser

    					max-age
    						max-age=60
    							cache for 1 minute